/*
    Copyright (c) 2010, 2011 aizo ag, Zurich, Switzerland

    Author: Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>

    This file is part of dS Assistant.

    dS-Assistant is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS-Assistant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.

    NOTE: all APIs, especially the JSON API, offered by this application
          are subject to change without further notice.
*/

#ifdef HAVE_CONFIG_H
#include "autoconfig.h"
#endif

#include <stdio.h>
#include <json.h>
#include <limits.h>
#include <boost/shared_ptr.hpp>

#include "web_handler.h"
#include "ds-assistant.h"
#include "exceptions.h"
#include "storage.h"

namespace dSA
{

WebHandler::WebHandler(struct mg_connection* connection,
                       const struct mg_request_info* request_info) :
                       m_connection(connection), m_request_info(request_info)
{

    if (m_request_info->uri)
    {
        m_command = webutil::command_from_uri(m_request_info->uri);
    }

    if (m_request_info->query_string)
    {
        webutil::parse_query(m_request_info->query_string, m_parameters);
    }
}

WebHandler::~WebHandler() {}

long long int WebHandler::getOptionalLLIntParam(std::string parameter,
                                                long long int defaultValue,
                                                std::string name)
{
    long long int ret;

    if (parameter.empty())
    {
        ret = defaultValue;
    }
    else
    {
        try
        {
            ret = util::str2llint(parameter);
        }
        catch (Exception &ex)
        {
            throw _Exception("invalid " + name + " parameter " +
                             ex.getMessage());
        }
    }

    return ret;
}

int WebHandler::getOptionalIntParam(std::string parameter, int defaultValue,
                                    std::string name)
{
    long long int ret = getOptionalLLIntParam(parameter, defaultValue, name);
    if ((ret > INT_MAX) || (ret < INT_MIN))
    {
        throw _Exception("parameter " + name + " out of range");
    }

    return (int)ret;
}

} // namespace

